@@ -1,9 +1,8 @@
 package Task::Lingua::Any::Numbers;
 use strict;
 use warnings;
-use vars qw( $VERSION );
 
-$VERSION = '0.17';
+our $VERSION = '0.18';
 
 1;
 
@@ -11,6 +10,8 @@ __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Task::Lingua::Any::Numbers - Installs all number to word modules.
@@ -21,8 +22,8 @@ None.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.17> of C<Task::Lingua::Any::Numbers>
-released on C<10 February 2011>.
+This document describes version C<0.18> of C<Task::Lingua::Any::Numbers>
+released on C<9 September 2012>.
 
 This is a tool to install everything needed for a full L<Lingua::Any::Numbers>
 interface. See the L<Task> module for the rationale.
@@ -55,26 +56,17 @@ interface. See the L<Task> module for the rationale.
 
 L<Lingua::Any::Numbers>, L<Task>.
 
-=head1 SUPPORT
-
-=head2 BUG REPORTS
-
-All bug reports and wishlist items B<must> be reported via
-the CPAN RT system. It is accessible at
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Task-Lingua-Any-Numbers>.
-
 =head1 AUTHOR
 
 Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2009 - 2011 Burak Gursoy. All rights reserved.
+Copyright 2009 - 2012 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.1 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.12.3 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
